@@ -1,5 +1,5 @@
-install <- function(pkgdir, dependencies, quiet, build, build_opts, upgrade,
-                    repos, type, ...) {
+install <- function(pkgdir, dependencies, quiet, build, build_opts, build_manual, build_vignettes,
+                    upgrade, repos, type, ...) {
 
   warn_for_potential_errors()
 
@@ -21,14 +21,16 @@ install <- function(pkgdir, dependencies, quiet, build, build_opts, upgrade,
   }
 
   install_deps(pkgdir, dependencies = dependencies, quiet = quiet,
-    build = build, build_opts = build_opts, upgrade = upgrade, repos = repos, type = type)
+    build = build, build_opts = build_opts, build_manual = build_manual,
+    build_vignettes = build_vignettes, upgrade = upgrade, repos = repos,
+    type = type)
 
   if (isTRUE(build)) {
     dir <- tempfile()
     dir.create(dir)
     on.exit(unlink(dir), add = TRUE)
 
-    pkgdir <- safe_build_package(pkgdir, build_opts, dir, quiet)
+    pkgdir <- safe_build_package(pkgdir, build_opts, build_manual, build_vignettes, dir, quiet)
   }
 
   safe_install_packages(
@@ -54,27 +56,47 @@ safe_install_packages <- function(...) {
     i.p <- utils::install.packages
   }
 
-  with_envvar(
-    c(R_LIBS = lib,
-      R_LIBS_USER = lib,
-      R_LIBS_SITE = lib,
-      RGL_USE_NULL = "TRUE"),
+  with_options(list(install.lock = getOption("install.lock", TRUE)), {
+    with_envvar(
+      c(R_LIBS = lib,
+        R_LIBS_USER = lib,
+        R_LIBS_SITE = lib,
+        RGL_USE_NULL = "TRUE"),
 
-    # Set options(warn = 2) for this process and child processes, so that
-    # warnings from `install.packages()` are converted to errors.
-    if (should_error_for_warnings()) {
-      with_options(list(warn = 2),
-        with_rprofile_user("options(warn = 2)",
-          i.p(...)
+      # Set options(warn = 2) for this process and child processes, so that
+      # warnings from `install.packages()` are converted to errors.
+      if (should_error_for_warnings()) {
+        with_options(list(warn = 2),
+          with_rprofile_user("options(warn = 2)",
+            i.p(...)
+          )
         )
-      )
-    } else {
-      i.p(...)
-    }
-  )
+      } else {
+        i.p(...)
+      }
+    )
+  })
 }
 
-safe_build_package <- function(pkgdir, build_opts, dest_path, quiet, use_pkgbuild = !is_standalone() && pkg_installed("pkgbuild")) {
+normalize_build_opts <- function(build_opts, build_manual, build_vignettes) {
+  if (!isTRUE(build_manual)) {
+    build_opts <- union(build_opts, "--no-manual")
+  } else {
+    build_opts <- setdiff(build_opts, "--no-manual")
+  }
+
+  if (!isTRUE(build_vignettes)) {
+    build_opts <- union(build_opts, "--no-build-vignettes")
+  } else {
+    build_opts <- setdiff(build_opts, "--no-build-vignettes")
+  }
+
+  build_opts
+}
+
+safe_build_package <- function(pkgdir, build_opts, build_manual, build_vignettes, dest_path, quiet, use_pkgbuild = !is_standalone() && pkg_installed("pkgbuild")) {
+  build_opts <- normalize_build_opts(build_opts, build_manual, build_vignettes)
+
   if (use_pkgbuild) {
     vignettes <- TRUE
     manual <- FALSE
@@ -92,7 +114,7 @@ safe_build_package <- function(pkgdir, build_opts, dest_path, quiet, use_pkgbuil
   } else {
     # No pkgbuild, so we need to call R CMD build ourselves
 
-    lib <- paste(.libPaths(), collapse = ":")
+    lib <- paste(.libPaths(), collapse = .Platform$path.sep)
     env <- c(R_LIBS = lib,
       R_LIBS_USER = lib,
       R_LIBS_SITE = lib,
@@ -152,6 +174,8 @@ r_error_matches <- function(msg, str) {
 #' @param ... additional arguments passed to [utils::install.packages()].
 #' @param build If `TRUE` build the package before installing.
 #' @param build_opts Options to pass to `R CMD build`, only used when `build`
+#' @param build_manual If `FALSE`, don't build PDF manual ('--no-manual').
+#' @param build_vignettes If `FALSE`, don't build package vignettes ('--no-build-vignettes').
 #' is `TRUE`.
 #' @export
 #' @examples
@@ -164,6 +188,7 @@ install_deps <- function(pkgdir = ".", dependencies = NA,
                          quiet = FALSE,
                          build = TRUE,
                          build_opts = c("--no-resave-data", "--no-manual", "--no-build-vignettes"),
+                         build_manual = FALSE, build_vignettes = FALSE,
                          ...) {
   packages <- dev_package_deps(
     pkgdir,
@@ -181,6 +206,9 @@ install_deps <- function(pkgdir = ".", dependencies = NA,
     upgrade = upgrade,
     build = build,
     build_opts = build_opts,
+    build_manual = build_manual,
+    build_vignettes = build_vignettes,
+    type = type,
     ...
   )
 }
@@ -189,7 +217,7 @@ should_error_for_warnings <- function() {
 
   force_suggests <- Sys.getenv("_R_CHECK_FORCE_SUGGESTS_", "true")
 
-  no_errors <- Sys.getenv("R_REMOTES_NO_ERRORS_FROM_WARNINGS", !as.logical(force_suggests))
+  no_errors <- Sys.getenv("R_REMOTES_NO_ERRORS_FROM_WARNINGS", !config_val_to_logical(force_suggests))
 
-  !as.logical(no_errors)
+  !config_val_to_logical(no_errors)
 }
